@@ -1,4 +1,4 @@
-from pydantic import BaseModel
+from pydantic import BaseModel, create_model
 from typing import Any
 
 class BaseSchema(BaseModel):
@@ -27,4 +27,6 @@ class BaseSchema(BaseModel):
                         newDatas[key] = annots[key](**data)
                         continue
             newDatas[key] = data
-        return newDatas
\ No newline at end of file
+        return newDatas
+
+json_model = create_model
\ No newline at end of file
