@@ -203,6 +203,10 @@ class SwaggerGenerator(Blueprint):
                 }
                 if po.description:
                     schema["description"] = po.description
+                if po.example:
+                    schema["example"] = po.example
+                if po.default.__class__ not in [None.__class__, Ellipsis.__class__]:
+                    schema["default"] = po.default
                 if "definitions" in sub_schema:
                     definitions.update(sub_schema.pop("definitions"))
                     allof = sub_schema.pop("properties")[k]
@@ -241,8 +245,7 @@ class SwaggerGenerator(Blueprint):
             force_type: Optional[Any] = None,
         ):
         all_forms = []
-        i = 0
-        for k, p in paired_params.items():
+        for i, (k, p) in enumerate(paired_params.items()):
             if type(p.param_object) == params_type:
                 ptype = force_type if force_type else p._type
                 ss = create_model(
@@ -252,7 +255,6 @@ class SwaggerGenerator(Blueprint):
                 all_forms.append(
                     ss.schema(ref_template="#/components/schemas/{model}")
                 )
-                i += 1
         return all_forms
     
     def generate_body_form_schema(self, name, paired_params):
